<?
/**
* Secure URI
*
* sURI class
*
* PHP version 5
*
* LICENSE: BSD license
*
* @category   pear
* @package    sUIR
* @author     JoungKyun.Kim <http://oops.org>
* @copyright  1997-2009 OOPS.ORG
* @license    BSD License
* @version    CVS: $Id: sURI.php,v 1.2 2009/02/26 05:30:35 oops Exp $
* @link       http://pear.php.net/package/sURI
* @since      File available since Release 0.1
*/

require_once 'sURI/Parser.php';
sURI_Parser::magic_quotes_gpc_off ();

global $post;
global $get;
global $cookie;

/**#@+
 * HTML version constants
 */
define ('HTML2', 0);
define ('HTML3', 1);
define ('HTML4', 2);
define ('HTML41', 3);
define ('HTML5', 4);
define ('XHTML10', 10);
define ('XHTML11', 11);
define ('XHTML12', 12);
define ('XHTML12', 13);
/**#@-*/

/**
 * Base clasee for Secure URI class
 */
class sURI extends sURI_Parser {
	// {{{ properties

	/**
	 * Set Error Messages
	 *
	 * @var    string
	 * @access public
	 */
	public $errstring;

	/**
	 * Set html version
	 *
	 * @var    int HTML2/HTML3/HTML4/HTML4.1/HTML5/XHTML10/XHTML11/XHTML12/XHTML/13
	 * @access public
	 */
	public  $htmlver;
	public  $charset;
	// }}}

	public $xhtmlclose;
	public $urlencode;
	public $eprefix = 0;

	public $legacy = false;
	public $hashtype = 0;

    public $allow_url_block = true;
	public $allow_url_blocks = array ();

	// {{{ constructor
	/**
	 * @access public
	 * @param int $htmlver (optional) defaults to (constant) HTML41
	 * @return void
	 */
	function __construct ($htmlver = HTML41, $charset = 'utf-8') {
		$this->set_xhtml ($htmlver);
		$this->set_urlencode ();
		$this->charset = $charset;
	}
	// }}}

	// {{{ set_xhtml
	/**
	 * Set XHTML close tag
	 *
	 * @param $value (optional) defaults to HTML41
	 * @access public
	 * @return void
	 */
	function set_xhtml ($value = HTML41) {
		$this->htmlver = $value;
		$this->xhtmlclose = ( $value >= XHTML10 ) ? ' /' : '';
	}
	// }}}

	// {{{ set_hash_type
	/**
	 * Set valid hash type
	 *
	 * @access public
	 * @return void
	 */
	function set_hash_type ($type = false) {
		if ( $type !== false ) {
			if ( $type >= $GLOBALS['hashno'] ) {
				echo ('ERROR: Unsupported Hash Type');
				exit;
			}
			$this->hashtype = $type;
			return;
		}

		if ( $_GET['hashtype'] )
			$_htype = $_GET['hashtype'];
		else if ( $_POST['hashtype'] )
			$_htype = $_POST['hashtype'];

		if ( is_numeric ($_htype) && $_htype < $GLOBALS['hashno'] )
			$this->hashtype = $_htype;
	}
	// }}}

	// {{{ set_urlencode
	/**
	 * Set true, string is urlencoded
	 *
	 * @param bool $value (optional) defaults to false
	 * @access public
	 * @return void
	 */
	function set_urlencode ($v = false) {
		$this->urlencode = $v;
	}
	// }}}

	// {{{ set_allow_block_url
	/**
	 * Set true, don't parse url on adjusted block
	 *
	 * @param bool $value (optional) defaults to false
	 * @access public
	 * @return void
	 */
	function set_allow_url_block ($v = false) {
		if ( is_array ($v) ) {
			$this->allow_url_block = true;
			$this->allow_url_blocks = $v;
			return;
		}

		$this->allow_url_block = false;
	}
	// }}}

	// {{{ set_legacy
	/**
	 * Set true, allow legacy uri parameter format
	 *
	 * @param bool $value (optional) defaults to false
	 * @access public
	 * @return void
	 */
	function set_legacy ($v = true) {
		$this->legacy = $v;
	}
	// }}}

	// {{{ set_error
	/**
	 * Set true, string is urlencoded
	 *
	 * @param string $value
	 * @access public
	 * @return void
	 */
	function set_error ($value = null) {
		if ( ! trim ($value) )
			return;

		$rpx = $this->eprefix + 8;
		$trace = debug_backtrace ();

		/*
		echo "<pre>";
		print_r ($trace);
		exit;
		 */

		$this->errstring = sprintf (
			"%-{$prx}s : %s line %d\n%-{$prx}s : %s\n%-{$prx}s : %s\n",
			'FILE', $trace[0]['file'], $trace[0]['line'],
			'Function', $trace[1]['class'] ?
						$trace[1]['class'] . '::' . $trace[1]['function'] :
						$trace[1]['function'],
			'Message', $value
		);
	}
	// }}}

	// {{{ destructor
	/**
	 * @access public
	 * @return void
	 */
	function __destruct () { }
	// }}}
}
?>
